@@ -11,7 +11,7 @@ from pytorch_lightning import LightningDataModule, loggers as pl_loggers
 from sklearn.model_selection import  train_test_split
 from sklearn.metrics import roc_auc_score
 import numpy as np
-from typing import Union, List, Dict, Any, Optional, cast, overload
+from typing import Union, List, Dict, Any, Optional, Tuple, cast, overload
 
 from sklearn.base import BaseEstimator
 import pickle, os, json, sys
@@ -310,7 +310,7 @@ class BaseExperiment:
 
     def get_data_module(
         self
-    )->Union["pl.LightningDataModule", tuple["np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray"]]:
+    )->Union["pl.LightningDataModule", Tuple["np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray"]]:
         r"""Method for getting a datamodule.
 
         Returns:
