@@ -11,7 +11,7 @@ from astrape.experiment import Experiment
 from astrape.models.models_lightning import *
 from astrape.constants.astrape_constants import *
 import numpy as np
-from typing import Union, List, Dict, Any, Optional, cast, overload
+from typing import Union, List, Dict, Any, Tuple, Optional, cast, overload
 import pytorch_lightning as pl
 from sklearn.base import BaseEstimator
 import os, json
